@@ -1,18 +1,15 @@
 from viset.caltech import Caltech101
 from viset.dataset import Viset
 from viset.show import imshow
-from time import sleep
 
 def main():
-  # Create a new viset
   print 'Creating vision dataset for Caltech101 dataset'
   dbfile = Caltech101().export()
   print 'Exporting Caltech101 dataset to redistributable HDF5 file "' + dbfile + '"'
 
-  # Import an existing viset 
   print 'Displaying all images in viset (VISion dataSET) "' + dbfile + '"'
-  db = Viset(dbfile, datastep=100)
-  for (im,annotation) in db['dataset']:
+  db = Viset(dbfile, datastep=100, asyncread=False, verbose=True)
+  for (im,annotation) in db[0]:
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
     imshow(im, title=annotation['category'])
 
