@@ -3,19 +3,17 @@ from viset.dataset import Viset
 from viset.show import imshow
 
 if __name__ == '__main__':
-  # Create a new viset
   print 'Creating vision dataset for Caltech256 dataset'
   dbfile = Caltech256().export()
   print 'Exporting Caltech256 dataset to redistributable HDF5 file "' + dbfile + '"'
   
-  # Import an existing viset 
   print 'Displaying all images in viset (VISion dataSET) "' + dbfile + '"'
-  db = Viset(dbfile, datastep=100)
+  db = Viset(dbfile, asycread=False, datastep=100)
   for (im,annotation) in db['dataset']:
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
     imshow(im)
 
   # Cleanup cached data (optional)
-  #db.delete()
+  db.delete()
 
   
