@@ -3,15 +3,15 @@ from viset.dataset import Viset
 from viset.show import imshow
 
 if __name__ == '__main__':
-  # Create a new viset
   print 'Creating vision dataset for imagenet-fall2011'
-  dbfile = ImageNetFall2011().export()
+  #dbfile = ImageNetFall2011().export()
+  dbfile = 'imagenet_fall2011.h5'
   print 'Exporting dataset to redistributable HDF5 file "' + dbfile + '"'
   
   # Import an existing viset 
   print 'Displaying all images in viset (VISion dataSET) "' + dbfile + '"'
-  db = Viset(dbfile, datastep=100)
-  for (im,annotation) in db['dataset']:
+  db = Viset(dbfile, datastep=100, asyncread=False, verbose=True)
+  for (im,annotation) in db[0]:
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
     if im is not None:
       imshow(im)
