@@ -1,8 +1,6 @@
 """Helpers to download and extract archives"""
 
-# Authors: Jeffrey Byrne <jeff@visym.com>
-#
-# Adapted from original authors below
+# Adapted for viset from original authors below
 # 
 # Authors: Nicolas Pinto <pinto@rowland.harvard.edu>
 #          Nicolas Poilvert <poilvert@rowland.harvard.edu>
@@ -40,6 +38,8 @@ def verify_md5(filename, md5):
 def download(url, output_filename, sha1=None, verbose=True, md5=None):
     """Downloads file at `url` and write it in `output_dirname`"""
 
+    # socket.setdefaulttimeout(10)  # do not set globally
+        
     page = urlopen(url)
     page_info = page.info()
 
@@ -87,6 +87,7 @@ def extract(archive_filename, output_dirname, sha1=None, verbose=True):
     -------------------
     * Zip formats and equivalents: .zip, .egg, .jar
     * Tar and compressed tar formats: .tar, .tar.gz, .tgz, .tar.bz2, .tz2
+    * gzip compressed files
     """
     if verbose:
         print "Extracting '%s' to '%s'" % (archive_filename, output_dirname)
@@ -107,3 +108,4 @@ def download_and_extract(url, output_dirname, sha1=None, verbose=True):
     archive_filename = path.join(output_dirname, archive_basename)
     download(url, archive_filename, sha1=sha1, verbose=verbose)
     extract(archive_filename, output_dirname, sha1=sha1, verbose=verbose)
+
